@@ -3,14 +3,15 @@
 void Parser::setLtype()
 {
     if (d_locationDecl.size())
-        lineMsg() << "%location-struct or %ltype multiply declared" << err;
+        lineMsg(emsg) << "%location-struct or %ltype multiply declared" << 
+                                                                        endl;
     else
     {
         char const *txt = d_scanner.YYText();
 
         if (strchr(txt, ';'))
-            lineMsg() << "`;' in %ltype type-definition `" << txt << "'" << 
-                                                                        err;
+            lineMsg(emsg) << "`;' in %ltype type-definition `" << txt << 
+                                                                '\'' << endl;
         else
         { 
             ((d_locationDecl = "typedef ") += txt) += " LTYPE__;\n";
