@@ -3,14 +3,14 @@
 void Parser::setStype()
 {
     if (d_stackDecl.size())
-        lineMsg() << "%union or %stype multiply specified" << err;
+        lineMsg(emsg) << "%union or %stype multiply specified" << endl;
     else
     {
         char const *txt = d_scanner.YYText();
 
         if (strchr(txt, ';'))
-            lineMsg() << "`;' in %stype type-definition `" << txt << "'" << 
-                                                                        err;
+            lineMsg(emsg) << "`;' in %stype type-definition `" << txt << 
+                                                                '\'' << endl;
         else
             ((d_stackDecl = "typedef ") += txt) += " STYPE__;\n";
     }
