@@ -93,9 +93,6 @@ class Scanner: private yyFlexLexer
         void hexadecimal();
         int setNumber();
         int yytextChk(int *nKept, int minLength, int ret);
-
-        static bool checkFilename(FileInfo const &info, 
-                                    std::string const &nextSource);
 };
 
 inline Block &Scanner::block()
@@ -113,12 +110,6 @@ inline size_t Scanner::number() const
     return d_number;
 }
 
-inline bool Scanner::checkFilename(FileInfo const &info, 
-                                    std::string const &nextSource)
-{
-    return info.d_name == nextSource;
-}
-
 inline std::string const &Scanner::sourceName() const
 {
     return d_fileInfo.back().d_name;
