@@ -7,13 +7,8 @@
 
 void SRConflict::inspect()
 {
-    for_each(
-        d_reducible.begin(), d_reducible.end(), 
-        [this](size_t idx)
-        {
-            this->visitReduction(idx);
-        }
-    );
+    for (auto idx: d_reducible)
+        visitReduction(idx);
 }
 
 
