@@ -8,7 +8,7 @@ ostream &State::insertStd(ostream &out) const
         out << d_itemVector[idx] << '\n';
 
     for (size_t idx = 0; idx < d_nextVector.size(); ++idx)
-        out << d_nextVector[idx] << '\n';
+        out << "  " << idx << d_nextVector[idx] << '\n';
 
     for (size_t idx = 0; idx < d_reducible.size(); ++idx)
         out << "  Reduce by " << d_itemVector[d_reducible[idx]] << '\n';
