@@ -14,21 +14,11 @@ void Writer::symbolicNames() const
         "    SMapVal(256, \"_error_\"),\n"
         "\n";
 
-    for_each(
-        d_rules.terminals().begin(), d_rules.terminals().end(),
-        [=](Terminal const *terminal)
-        {
-            terminalSymbol(terminal, *d_out);
-        }
-    );
+    for (auto terminal: d_rules.terminals())
+        terminalSymbol(terminal, *d_out);
 
-    for_each(
-        d_rules.nonTerminals().begin(), d_rules.nonTerminals().end(),
-        [=](NonTerminal const *nonTerminal)
-        {
-            nonTerminalSymbol(nonTerminal, *d_out);
-        }
-    );
+    for (auto nonTerminal: d_rules.nonTerminals())
+        nonTerminalSymbol(nonTerminal, *d_out);
 
     *d_out <<  "};\n"
             "\n"
